@@ -1,6 +1,6 @@
 from __future__ import print_function, absolute_import
 
-from torchreid.reid.data.datasets import (
+from torchreid.reid.data.datasets.dataset import (
     Dataset, ImageDataset, VideoDataset, register_image_dataset,
     register_video_dataset
 )
